@@ -16,9 +16,13 @@ exports = module.exports = LCov;
 
 function LCov(runner) {
   runner.on('end', function(){
-    // In a browser context, coverage will be in window.$jscoverage.
+    // In a browser context, coverage will be in window.$jscoverage or window._$blanket.
     var g = typeof(global) != 'undefined' ? global : window;
-    var cov = g._$jscoverage || {};
+    var cov = g._$jscoverage || g._$blanket;
+    if (!cov) {
+        console.error('mocha-lcov-reporter: No coverage data found, make sure your code is properly instrumented');
+        return;
+    }
 
     for (var filename in cov) {
       var data = cov[filename];
